
/*
   ************************************************************************
   ************************************************************************
   **                                                                    **
   **   Module Name  : SSWinCom32.h             Date : September 8, 1994 **
   **   Main Module  : SSWinCom32.c             Version : 1.0.0          **
   **   Design By    : Charles R. Grenz         Company : Magna Assoc.Inc**
   **   Designed for : Magna Associates, Inc.  (C)opyright 1994 - 1999   **
   **                                           All Rights Reserved      **
   **   Notes :                                                          **
   **        This software belongs to the following persons, and can not **
   **        be copied or used in any form without the express written   **
   **        permission of all the people listed. If portions of this    **
   **        software are used in another project, then a notice that    **
   **        portions of this software where copied, and are copyright   **
   **        by Magna Associates, Inc.                                   **
   **                                                                    **
   **                  Charles R. Grenz                                  **
   **                  Paul Webber                                       **
   **                                                                    **
   ************************************************************************
   ************************************************************************ */

/*********************************************************************
                         Defines for this Module
 *********************************************************************/

#define DWord_T                  unsigned long int
#define Lint_T                   long int
#define Byte_T                   unsigned char
#define Word_T                   unsigned int
#define Boolean_T                int
#define Float_T                  double
#define Mptr_T                   char far *

#define CNTL_Q                   (char) 0x11
#define CNTL_R                   (char) 0x12
#define CNTL_S                   (char) 0x13

#define S_MOTOR                  (Byte_T) 1  // Standard SSCB Motor
#define H_MOTOR                  (Byte_T) 2  // SSCB-HC Motor
#define X_MOTOR                  (Byte_T) 3  // Check X Motor
#define Y_MOTOR                  (Byte_T) 4  // Check Y Motor
#define Z_MOTOR                  (Byte_T) 5  // Check Z Motor
#define A_MOTOR                  (Byte_T) 6  // Check X,Y,Z Motors
#define Q_ENCODERS               (Byte_T) 7  // Quadrature Encoder Board

#define NO_COMM_ERROR            (Word_T) 0  // No Communications Error Occured
#define COMM_PORT_NOT_VALID      (Word_T) 1  // User Communications port not within the COM1-COM4 value (0-3)
#define COMM_BAUD_NOT_VALID      (Word_T) 2  // User Baudrate not valid (9600, 19200, 38400, 57600, 115200)
#define INVALID_COMM_PORT        (Word_T) 3  // Can not open port. (being used, or not there)
#define INVALID_DCB_STRUCT       (Word_T) 4  // Can not get communication port DCB status
#define INVALID_DCB_VALUE        (Word_T) 5  // Can not set communication port values because of a invalid parameter.
#define INVALID_TIMEOUT_VALUE    (Word_T) 6  // Can not set communication port timeout value because one or all of them are invalid.

/* ***************************************************************************
                     Variables for SSWinCom32.c
   *************************************************************************** */

extern Boolean_T far _import no_comm_messages;       // If TRUE, No Communication ERROR Dialogs will be shown (Default = FALSE)
extern Boolean_T far _import comm_activated;         // If TRUE, Communications Port has been Opened and Initialized
extern int far _import user_port;                    // Currently Selected Communications Port (COM1 = 0, COM2 = 1, COM3 = 2, and COM4 = 3)
extern Word_T far _import user_codes;                // This variable is used in the check_message() routine
extern DWord_T far _import txd_timer;                // Transmission pacing timout in milliseconds, 0 = None

extern Boolean_T far _import sscb[17];               // If flag is set TRUE, then SSCB is at that board address
extern Boolean_T far _import sscbhc[17];             // If flag is set TRUE, then SSCB-HC is at that board address
extern Boolean_T far _import ssqe[17];               // If flag is set TRUE, then SSQE is at that board address
extern Boolean_T far _import ssxyz[17];              // If flag is set TRUE, then SSXYZ is at that board address

extern Byte_T far _import sscb_count;                // How many SSCB's are online
extern char far _import message_sscb_count[10];      // String version of the above variable

extern Byte_T far _import sscbhc_count;              // How many SSCB-HC's are online
extern char far _import message_sscbhc_count[10];    // String version of the above variable

extern Byte_T far _import ssxyz_count;               // How many SSXYZ's are online
extern char far _import message_ssxyz_count[10];     // String version of the above variable

extern Byte_T far _import ssqe_count;                // How many SSQE's are online
extern char far _import message_ssqe_count[10];      // String version of the above variable

extern char far _import message_sscb_command[150];   // Last string Command sent to board
extern char far _import message_sscb_select[10];     // Currently selected board
extern char far _import message_sscb_status[20];     // Last string status from board

extern char far _import message_sscbhc_command[150]; // Last string Command sent to board
extern char far _import message_sscbhc_select[10];   // Currently selected board
extern char far _import message_sscbhc_status[20];   // Last string status from board

extern char far _import message_ssxyz_command[150];  // Last string Command sent to board
extern char far _import message_ssxyz_select[10];    // Currently selected board
extern char far _import message_ssxyz_status[20];    // Last string status from board

extern char far _import message_ssqe_command[50];    // Last string Command sent to board
extern char far _import message_ssqe_select[10];     // Currently selected board
extern char far _import message_ssqe_status[20];     // Last string status from board

extern DWord_T  far _import baudrate;                // Current Baudrate of serial link
extern Word_T far _import comm_error;                // If a Communications error occured, value of comm error is held here. 0 = None

extern const char _import sswincom32_date[];         // Date DLL was compiled
extern const char _import sswincom32_time[];         // Time DLL was compiled
extern const char _import sswincom32_file[];         // Filename DLL was compiled
extern const char _import sswincom32_version[];      // Version Numbe of DLL

/* ***************************************************************************
                       Procedures used in SSWinCom32.c
   *************************************************************************** */

extern Boolean_T far _import pascal check_messages(void);          // Returns TRUE if message where found and needed to be posted
extern Boolean_T far _import pascal check_serial_output(void);     // If TRUE, data is in buffer waiting to be sent
extern Word_T far _import pascal check_serial_input(void);         // Returns the amount of data being held in the reciever buffer
extern void far _import pascal clear_read_buffer(void);            // Erases all Input buffer data

extern void far _import pascal change_boards_baudrate(DWord_T baud_rate);  // Changes ALL boards on the Network to another baudrate, if ask_baud == TRUE, will ask the user to choose a baudrate first before setting it.
extern Boolean_T far _import pascal change_baudrate(DWord_T new_baud);

extern Boolean_T far _import pascal message_out(char far *msg);    // Transmitts a message out to the serial port
extern Boolean_T far _import pascal message_in(char far *msg);     // Recieves a message in from the serial port
extern Boolean_T far _import pascal wait_port(DWord_T wait_time);  // Returns TRUE if a message or character is found in the reciever buffer, else if wait_time expires, will return FALSE

extern void far _import pascal release_serial_port(void);          // Releases current serial port so that other programs are allowed to use it

extern Boolean_T far _import pascal initialize_comm_module(Byte_T com_port,      // Communications Port to Initialize (COM1 = 0 ... COM4 = 3)
                                         DWord_T baud_rate,    // Communications Baudrate (9600 - 115200)
                                         DWord_T wait_time,    // Delay time before aborting a receive message wait_port routine in milliseconds
                                         DWord_T txd_pacing_time);  // Delay time to transmitt characters out the serial port (0 = OFF) in milliseconds

extern int far _import pascal delay(DWord_T wait_time);                     // Delays wait_time in milliseconds (checks for system messages while waiting)
extern int far _import pascal seconds_delay(DWord_T wait_time);             // Delays wait_time in seconds (checks for system messages while waiting)

extern char far _export pascal raw_character_in(void);                  // Raw Character Read from Serial Port
extern Boolean_T far _export pascal raw_character_out(char far msg);    // Raw Character Send to Serial Port


/* ***************************************************************************
   *************************************************************************** */


